#!/usr/bin/python
# encoding: utf-8
"""
===========================证件照成品接口===========================
"""

import requests
import json
import base64
import hashlib


class Idphoto:
    def __init__(self, appcode, timeout=7):
        self.appcode = appcode
        self.timeout = timeout
        self.idphoto_detect_url = 'https://idpdetect.market.alicloudapi.com/idphoto/detect'

        self.headers = {
            'Authorization': 'APPCODE ' + appcode,
        }

    def get_md5_data(self, body):
        """
        md5加密
        :param body_json:
        :return:
        """

        md5lib = hashlib.md5()
        md5lib.update(body.encode("utf-8"))
        body_md5 = md5lib.digest()
        body_md5 = base64.b64encode(body_md5)
        return body_md5

    def get_photo_base64(self, file_path):
        with open(file_path, 'rb') as fp:
            photo_base64 = base64.b64encode(fp.read())

        photo_base64 = photo_base64.decode('utf8')
        return photo_base64

    def aiseg_request(self, url, data, headers):
        resp = requests.post(url=url, data=data, headers=headers, timeout=self.timeout)
        res = {"status_code": resp.status_code}
        try:
            res["data"] = json.loads(resp.text)
            return res
        except Exception as e:
            print(e)

        return data

    def idphoto_detect(self, file_path, photo_key=None):
        """
        证件照成品检测接口
        photo和photo_key设置一个即可，如果两个都设置，则使用photo参数
        :param photo:
        :param photo_key:
        :return:
        """
        if file_path:
            photo_base64 = self.get_photo_base64(file_path)
        else:
            photo_base64 = ""

        body_json = {
            "photo": photo_base64,
            # "photo_key": photo_key
        }

        body = json.dumps(body_json)
        body_md5 = self.get_md5_data(body=body)
        self.headers.update({'Content-MD5': body_md5})

        data = self.aiseg_request(url=self.idphoto_detect_url, data=body, headers=self.headers)
        return data


if __name__ == "__main__":
    file_path = "1.jpg"

    idphoto = Idphoto(appcode="你的appcode")

    # 成品检测
    d = idphoto.idphoto_detect(file_path)
    print(d)
